#!/usr/bin/perl
#########################################################################
####                                                                #####
####                           CSV to SQL                           #####
####                                                                #####
####    domisse@iap.fr                       version 05/09/2004     #####
####                                                                #####
#########################################################################

my $version = "1.03";
my $verdate = "05/09/04";

###
### Syntax : convert_csv2sql.pl > standard.sql
###

#
### Init
#

#$make_landolt = 1; # Choose to convert the landolt csv file
#$make_sloan = 1;   # Choose to convert the sloan csv file
$make_stetson = 1;   # Choose to convert the stetson csv file

#
### Database Fields from the csv files
#

### Sloan

@keyword_sloan = ('Star','dbRA','dbDEC','Ra_deg','Dec_deg','r','u-g','g-r','r-i','i-z','sigma_r','sigma_u-g','sigma_g-r','sigma_r-i','sigma_i-z','n_u','n_g','n_r','n_i','n_z');
@keyword_sloan_type = ('varchar(80)','varchar(80)','varchar(80)','double','double','double','double','double','double','double','double','double','double','double','double','double','double','double','double','double');

@keyword_cancel_sloan = (''); # if you want to cancel some fields from the CSV file

### Landolt

@keyword_landolt = ('Star','Chart','dbRA','dbDEC','Ra_deg','Dec_deg','V','B-V','U-B','V-R','R-I','V-I','n','m','e_V','e_B-V','e_U-B','e_V-R','e_R-I','e_V-I');
@keyword_landolt_type = ('varchar(80)','varchar(80)','varchar(80)','varchar(80)','double','double','double','double','double','double','double','double','double','double','double','double','double','double','double','double');

@keyword_cancel_landolt = ('Chart');  # if you want to cancel some fields from the CSV file

### Stetson

@keyword_stetson = ('Star','dbRA','dbDEC','Ra_deg','Dec_deg','B','V','R','I');
@keyword_stetson_type = ('varchar(80)','varchar(80)','varchar(80)','double','double','double','double','double','double');

@keyword_cancel_stetson = (''); # if you want to cancel some fields from the CSV file


################################### SLOAN #################################################

if ($make_sloan == 1) {

    $create_query = "CREATE TABLE `Sloan` (";

    for ($i=0;$i<=$#keyword_sloan;$i++) {
	$abort = 0;
	for ($j=0;$j<=$#keyword_cancel_sloan;$j++) {
	    if ($keyword_cancel_sloan[$j] eq $keyword_sloan[$i]) {
		$abort = 1;
		push(@array_sloan_nb,$i);
	    }
	}
	if ($abort == 0) {
	    $create_query .= "`$keyword_sloan[$i]` $keyword_sloan_type[$i] NOT NULL";
	}
	$create_query .= "," if ($i != $#keyword_sloan);
    }
    $create_query .= ") TYPE=MyISAM";
    
    print "$create_query\n";

#
    
    open(FILE,"sloan.csv");
    while (<FILE>) {
	chop;
	$line = $_;
	(@tmp) = split(/,/,$line);
	$query = "INSERT INTO Sloan (";
	for ($i=0;$i<=$#keyword_sloan;$i++) {
	    $abort = 0;
	    for ($j=0;$j<=$#array_sloan_nb;$j++) {
		$abort = 1 if ($array_sloan_nb[$j] == $i);
	    }
	    if ($abort == 0) {
		$query .= "`$keyword_sloan[$i]`";
		$query .= "," if ($i != $#keyword_sloan);
	}
	    
	}
	$query .= ") VALUES (";
	for ($i=0;$i<=$#tmp;$i++) {
	    $abort = 0;
	    for ($j=0;$j<=$#array_sloan_nb;$j++) {
		$abort = 1 if ($array_sloan_nb[$j] == $i);
	    }
	if ($abort == 0) {
	    $tmp[$i] =~ s/\s/:/g if ($keyword_sloan[$i] eq "dbRA");
	    $tmp[$i] =~ s/\s/:/g if ($keyword_sloan[$i] eq "dbDEC");
	    $ra = $tmp[$i] if ($keyword_sloan[$i] eq "dbRA");
	    $dec = $tmp[$i] if ($keyword_sloan[$i] eq "dbDEC");

	    $query .= "'$tmp[$i]'";
	    if ($keyword_sloan[$i] eq "dbDEC") {
		# Get Ra_deg from $ra and Dec_deg from $dec

		($tmp1,$tmp2,$tmp3) = split(/:/,$ra);
		$tmp1 = "0".$tmp1 if (length($tmp1) == 1);
		$tmp2 = "0".$tmp2 if (length($tmp2) == 1);
		$tmp3 = int($tmp3);
		$tmp3 = "0".$tmp3 if (length($tmp3) == 1);
		$ra_name = $tmp1.$tmp2.$tmp3;
		$ra_deg = $tmp1*3600+$tmp2*60+$tmp3;
		$ra_deg = ($ra_deg/240);
		$ra_deg = (int($ra_deg*1000000))/1000000;

		($tmp1,$tmp2,$tmp3) = split(/:/,$dec);
		$sign_decl = "" if ($tmp1 < 0);
		$sign_decl = "+" if ($tmp1 >= 0);
		$tmp1 = "0".$tmp1 if (length($tmp1) == 1);
		$tmp2 = "0".$tmp2 if (length($tmp2) == 1);
		$tmp3 = int($tmp3);
		$tmp3 = "0".$tmp3 if (length($tmp3) == 1);
		$decl_name = $sign_decl.$tmp1.$tmp2.$tmp3;
		$decl_deg = $tmp1+($tmp2/60)+($tmp3/3600) if ($tmp1 >= 0);
		$decl_deg = $tmp1-($tmp2/60)-($tmp3/3600) if ($tmp1 < 0);
		$decl_deg = (int($decl_deg*1000000))/1000000;

		$query .= ",'$ra_deg','$decl_deg'";
	    }
	    $query .= "," if ($i != $#tmp);
	}

	}
	$query .= ");\n";
	print "$query";

	# Add Ra_deg, Dec_deg from $ra,$dec


    }
    close(FILE);

}

################################### LANDOLT ###############################################


if ($make_landolt == 1) {

    $create_query = "CREATE TABLE `Landolt` (";

    for ($i=0;$i<=$#keyword_landolt;$i++) {
	$abort = 0;
	for ($j=0;$j<=$#keyword_cancel_landolt;$j++) {
	    if ($keyword_cancel_landolt[$j] eq $keyword_landolt[$i]) {
		$abort = 1;
		push(@array_landolt_nb,$i);
	    }
    }
	if ($abort == 0) {
	    $create_query .= "`$keyword_landolt[$i]` $keyword_landolt_type[$i] NOT NULL";
	}
	$create_query .= "," if ($i != $#keyword_landolt);
    }
    $create_query .= ") TYPE=MyISAM";

#  PRIMARY KEY  (`ItemID`),
#  UNIQUE KEY `Item` (`Item`(255),`Owner`(127)),
#  KEY `UserID` (`Owner`(255))
#) TYPE=MyISAM COMMENT='Cart Items' AUTO_INCREMENT=107 ;

    print "$create_query\n";

#

    open(FILE,"landolt.csv");
    while (<FILE>) {
	chop;
	$line = $_;
	(@tmp) = split(/,/,$line);
	$query = "INSERT INTO Landolt (";
	for ($i=0;$i<=$#keyword_landolt;$i++) {
	    $abort = 0;
	    for ($j=0;$j<=$#array_landolt_nb;$j++) {
		$abort = 1 if ($array_landolt_nb[$j] == $i);
	    }
	    if ($abort == 0) {
		$query .= "`$keyword_landolt[$i]`";
	    $query .= "," if ($i != $#keyword_landolt);
	}
	    
	}
	$query .= ") VALUES (";
	for ($i=0;$i<=$#tmp;$i++) {
	    $abort = 0;
	    for ($j=0;$j<=$#array_landolt_nb;$j++) {
		$abort = 1 if ($array_landolt_nb[$j] == $i);
	    }
	if ($abort == 0) {
	    $tmp[$i] =~ s/\s/:/g if ($keyword_landolt[$i] eq "dbRA");
	    $tmp[$i] =~ s/\s/:/g if ($keyword_landolt[$i] eq "dbDEC");
	    $ra = $tmp[$i] if ($keyword_landolt[$i] eq "dbRA");
	    $dec = $tmp[$i] if ($keyword_landolt[$i] eq "dbDEC");

	    $query .= "'$tmp[$i]'";
	    if ($keyword_landolt[$i] eq "dbDEC") {
		# Get Ra_deg from $ra and Dec_deg from $dec

		($tmp1,$tmp2,$tmp3) = split(/:/,$ra);
		$tmp1 = "0".$tmp1 if (length($tmp1) == 1);
		$tmp2 = "0".$tmp2 if (length($tmp2) == 1);
		$tmp3 = int($tmp3);
		$tmp3 = "0".$tmp3 if (length($tmp3) == 1);
		$ra_name = $tmp1.$tmp2.$tmp3;
		$ra_deg = $tmp1*3600+$tmp2*60+$tmp3;
		$ra_deg = ($ra_deg/240);
		$ra_deg = (int($ra_deg*1000000))/1000000;

		($tmp1,$tmp2,$tmp3) = split(/:/,$dec);
		$sign_decl = "" if ($tmp1 < 0);
		$sign_decl = "+" if ($tmp1 >= 0);
		$tmp1 = "0".$tmp1 if (length($tmp1) == 1);
		$tmp2 = "0".$tmp2 if (length($tmp2) == 1);
		$tmp3 = int($tmp3);
		$tmp3 = "0".$tmp3 if (length($tmp3) == 1);
		$decl_name = $sign_decl.$tmp1.$tmp2.$tmp3;
		$decl_deg = $tmp1+($tmp2/60)+($tmp3/3600) if ($tmp1 >= 0);
		$decl_deg = $tmp1-($tmp2/60)-($tmp3/3600) if ($tmp1 < 0);
		$decl_deg = (int($decl_deg*1000000))/1000000;

		$query .= ",'$ra_deg','$decl_deg'";
	    }
	    $query .= "," if ($i != $#tmp);
	}

	}
	$query .= ");\n";
	print "$query";
    }
    close(FILE);
}

################################### STETSON #################################################

if ($make_stetson == 1) {

    $create_query = "CREATE TABLE `Stetson` (";

    for ($i=0;$i<=$#keyword_stetson;$i++) {
	$abort = 0;
	for ($j=0;$j<=$#keyword_cancel_stetson;$j++) {
	    if ($keyword_cancel_stetson[$j] eq $keyword_stetson[$i]) {
		$abort = 1;
		push(@array_stetson_nb,$i);
	    }
	}
	if ($abort == 0) {
	    $create_query .= "`$keyword_stetson[$i]` $keyword_stetson_type[$i] NOT NULL";
	}
	$create_query .= "," if ($i != $#keyword_stetson);
    }
    $create_query .= ") TYPE=MyISAM";
    
    print "$create_query\n";

    open(FILE,"stetson.csv");
    while (<FILE>) {
	chop;
	$line = $_;
	(@tmp) = split(/,/,$line);
	$query = "INSERT INTO Stetson (";
	for ($i=0;$i<=$#keyword_stetson;$i++) {
	    $abort = 0;
	    for ($j=0;$j<=$#array_stetson_nb;$j++) {
		$abort = 1 if ($array_stetson_nb[$j] == $i);
	    }
	    if ($abort == 0) {
		$query .= "`$keyword_stetson[$i]`";
	    $query .= "," if ($i != $#keyword_stetson);
	}
	    
	}
	$query .= ") VALUES (";
	for ($i=0;$i<=$#tmp;$i++) {
	    $abort = 0;
	    for ($j=0;$j<=$#array_stetson_nb;$j++) {
		$abort = 1 if ($array_stetson_nb[$j] == $i);
	    }
	if ($abort == 0) {
	    $tmp[$i] =~ s/\s/:/g if ($keyword_stetson[$i] eq "dbRA");
	    $tmp[$i] =~ s/\s/:/g if ($keyword_stetson[$i] eq "dbDEC");
#	    $ra = $tmp[$i] if ($keyword_stetson[$i] eq "dbRA");
#	    $dec = $tmp[$i] if ($keyword_stetson[$i] eq "dbDEC");

	    $query .= "'$tmp[$i]'";

#	    if ($keyword_stetson[$i] eq "dbDEC") {
		# Get Ra_deg from $ra and Dec_deg from $dec

#		($tmp1,$tmp2,$tmp3) = split(/:/,$ra);
#		$tmp1 = "0".$tmp1 if (length($tmp1) == 1);
#		$tmp2 = "0".$tmp2 if (length($tmp2) == 1);
#		$tmp3 = int($tmp3);
#		$tmp3 = "0".$tmp3 if (length($tmp3) == 1);
#		$ra_name = $tmp1.$tmp2.$tmp3;
#		$ra_deg = $tmp1*3600+$tmp2*60+$tmp3;
#		$ra_deg = ($ra_deg/240);
#		$ra_deg = (int($ra_deg*1000000))/1000000;

#		($tmp1,$tmp2,$tmp3) = split(/:/,$dec);
#		$sign_decl = "" if ($tmp1 < 0);
#		$sign_decl = "+" if ($tmp1 >= 0);
#		$tmp1 = "0".$tmp1 if (length($tmp1) == 1);
#		$tmp2 = "0".$tmp2 if (length($tmp2) == 1);
#		$tmp3 = int($tmp3);
#		$tmp3 = "0".$tmp3 if (length($tmp3) == 1);
#		$decl_name = $sign_decl.$tmp1.$tmp2.$tmp3;
#		$decl_deg = $tmp1+($tmp2/60)+($tmp3/3600) if ($tmp1 >= 0);
#		$decl_deg = $tmp1-($tmp2/60)-($tmp3/3600) if ($tmp1 < 0);
#		$decl_deg = (int($decl_deg*1000000))/1000000;

#		$query .= ",'$ra_deg','$decl_deg'";
#	    }
	    $query .= "," if ($i != $#tmp);
	}

	}
	$query .= ");\n";
	print "$query";
    }
    close(FILE);

}
